Module engine

Module engine 

Interface definitions for async engines.

Traits

AsyncEngine
Defines the interface of an asynchronous background running engine.

Functions

start_engine
Starts the engine by spawning it in a new task.