Module error

Module error 

Definitions for common error types.

Structs

ClientCreationError
HTTP Client creation failed.

Enums

CommitHashError
Error in retrieving a commit or its info using git ls-remote.
FatalError
An error that requires the server to be shut down.
HandlerError
An error happened inside an Axum handler.
SetupError
Error about the setup configuration.
ValidationError
Validation error.