Module model

Module model 

Data structures representing items stored in database.

The Create_ structs represent the payload to create the corresponding row.

Structs

Branch
Represents a row in the branches table.
CreateSubscription
Holds payload data for the creation of a Subscription.
HalLink
HAL link structure.
SourceBranchInfo
Represents branch information for a subscription.
Subscription
Represents a row in the subscriptions table.
SubscriptionHal
HAL representation of a subscription.
SubscriptionLinks
HAL links for a subscription.
SubscriptionPage
Paginated representation of subscriptions.
SubscriptionPageLinks
HAL links for a subscription page.
SubscriptionWithBranch
Combined subscription and branch information.
TriggerQueueItem
Represents a row in the trigger_queue table.
UpdateSubscription
Holds payload data for the update of a Subscription.