Operations to fetch and extract git branch data from remote repositories.
Structs
- Main
GitFetcher - Runs git commands.
Traits
- GitFetcher
- Allows running git commands.
Operations to fetch and extract git branch data from remote repositories.