Interface definitions for async engines.
Traits
- Async
Engine - Defines the interface of an asynchronous background running engine.
Functions
- start_
engine - Starts the engine by spawning it in a new task.
Interface definitions for async engines.