Definitions for common error types.
Structs
- Client
Creation Error - HTTP Client creation failed.
Enums
- Commit
Hash Error - Error in retrieving a commit or its info using
git ls-remote. - Fatal
Error - An error that requires the server to be shut down.
- Handler
Error - An error happened inside an Axum handler.
- Setup
Error - Error about the setup configuration.
- Validation
Error - Validation error.