pub async fn __list_subscriptions_impl(
state: State<AppState>,
query: Query<ListSubscriptionsQuery>,
) -> Result<Json<SubscriptionPage>, HandlerError>Expand description
List subscriptions.
Returns a paginated list of all subscription mappings in the system.
Query Parameters
limit: The maximum number of subscriptions to return.last_id: The ID of the last subscription in the previous page.
Responses
200: Json
Metadata
@tag subscriptions