Asynchronous task to periodically check for updated remote branches.
Modules
- git
- Operations to fetch and extract git branch data from remote repositories.
Structs
- Polling
Engine - Runs an asynchronous task that periodically polls git branches in remote repositories.